==> flamerobin_0.7.6.orig.tar.gz: flamerobin-0.7.6-src/src/frutils.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: frutils.h 1098 2006-05-07 16:55:41Z mbabuskov $

*/

#ifndef FRUTILS_H
#define FRUTILS_H
//-----------------------------------------------------------------------------
#include <wx/wx.h>

#include <list>

#include <ibpp.h>

class Relation;
class Database;
class Server;
class ProgressDialog;
class ProgressIndicator;
//-----------------------------------------------------------------------------
//! sets all controls to width of widest control
void adjustControlsMinWidth(std::list<wxWindow*> controls);
//-----------------------------------------------------------------------------
//! reads blob from statement into wxString
void readBlob(IBPP::Statement& st, int column, wxString& result);
//-----------------------------------------------------------------------------
//! displays a list of table columns and lets user select some
wxString selectRelationColumns(Relation* t, wxWindow* parent);
bool selectRelationColumnsIntoVector(Relation* t, wxWindow* parent,
    std::vector<wxString>& list);
//-----------------------------------------------------------------------------
//! pops up message box with last error from database operations
void reportLastError(const wxString& actionMsg);
//-----------------------------------------------------------------------------
//! prompts for password if needed and connects to database
bool connectDatabase(Database *db, wxWindow* parent,
    ProgressDialog* progressdialog = 0);
//-----------------------------------------------------------------------------
bool getService(Server* s, IBPP::Service& svc, ProgressIndicator* p,
    bool sysdba);
//-----------------------------------------------------------------------------
#endif // FRUTILS_H

==> flamerobin_0.8.6.orig.tar.gz: flamerobin-0.8.6-src/src/frutils.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: frutils.h 1608 2007-12-26 23:03:26Z babuskov $

*/

#ifndef FRUTILS_H
#define FRUTILS_H
//-----------------------------------------------------------------------------
#include <wx/wx.h>
#include <wx/filename.h>

#include <list>

#include <ibpp.h>

class Relation;
class Database;
class Server;
class ProgressDialog;
class ProgressIndicator;
//-----------------------------------------------------------------------------
//! sets all controls to width of widest control
void adjustControlsMinWidth(std::list<wxWindow*> controls);
//-----------------------------------------------------------------------------
//! reads blob from statement into wxString
void readBlob(IBPP::Statement& st, int column, wxString& result);
//-----------------------------------------------------------------------------
//! displays a list of table columns and lets user select some
wxString selectRelationColumns(Relation* t, wxWindow* parent);
bool selectRelationColumnsIntoVector(Relation* t, wxWindow* parent,
    std::vector<wxString>& list);
//-----------------------------------------------------------------------------
//! prompts for password if needed and connects to database
bool connectDatabase(Database *db, wxWindow* parent,
    ProgressDialog* progressdialog = 0);
//-----------------------------------------------------------------------------
bool getService(Server* s, IBPP::Service& svc, ProgressIndicator* p,
    bool sysdba);
//-----------------------------------------------------------------------------
//! loads the file into wxString
wxString loadEntireFile(const wxString& filename);
wxString loadEntireFile(const wxFileName& filename);
//-----------------------------------------------------------------------------
#endif // FRUTILS_H
